require 'json'
require 'digest'
require 'net/http'

module Sms
  class Taobao

    attr_accessor :app_secret, :app_key, :sms_free_sign_name, :sms_template_code, :sms_param

    def initialize(options = {})
      self.app_secret = options[:app_secret]
      self.app_key = options[:app_key]
      self.sms_free_sign_name = options[:sms_free_sign_name]
      self.sms_template_code = options[:sms_template_code]
      self.sms_param = options[:sms_param] || {}
    end

    def singleSend(number)
      send(number.split)
    end

    def batchSend(numbers)
      send(numbers)
    end

    def defaultParams(numbers)
      {
          method: 'alibaba.aliqin.fc.sms.num.send',
          app_key: self.app_key,
          timestamp: Time.now.strftime("%Y-%m-%d %H:%M:%S"),
          format: 'json',
          v: 2.0,
          sign_method: 'md5',
          sms_type: 'normal',
          sms_free_sign_name: self.sms_free_sign_name,
          rec_num: numbers.join(','),
          sms_param: self.sms_param.to_json,
          sms_template_code: self.sms_template_code
      }
    end

    def generate_sign(params)
      str = params.to_a.map{|m| m.map(&:to_s).join }.sort.join
      Digest::MD5.hexdigest("#{app_secret.to_s}#{str}#{app_secret.to_s}").upcase
    end

    def send(numbers)
      params = defaultParams(numbers)
      params = params.merge(sign: generate_sign(params))
      data = request_api(params)
      data = JSON.parse(data.body)
      puts "data ************* #{data}"
      if data['alibaba_aliqin_fc_sms_num_send_response']['result']['success']
        data
      else
        false
      end
    rescue => e
      false
    end

    def request_api(params)
      Net::HTTP.post_form(URI.parse('http://gw.api.taobao.com/router/rest'), params)
    end

  end
end